#############################################################################
#############################################################################
###############                                                    ##########
###############       Cognitive Ability and Risk Aversion:         ##########
###############  A systematic Literature Review and Meta-Analysis  ##########
###############                                                    ##########
#############################################################################
#############################################################################


#############################################################################
##                                                                         ##
##  This R-script replicates the results from the paper:"Cognitive Ability ##
##  and Risk Aversion: A systematic Review and Meta-Analysis".             ##
##                                                                         ##
#############################################################################


###############################
##        Load packages      ##
###############################

  library("metafor")
  library("dplyr")
  library("readxl")

    
################################################ 
## Set working directory to data file path....## 
################################################

  setwd("~/Documents/Articles/Cognitive Ability & Risk Aversion (JDM)/Final Resubmission")

  
####################
## Load data.... ###
####################  

  Data_Gains<- read_excel("Final_Data_Gains.xlsx", 
                          col_types = c( "text", "numeric", 
                                        "numeric", "numeric", "numeric", 
                                        "numeric", "numeric", "numeric", 
                                        "numeric", "text", "text", "numeric", 
                                        "text", "text", "text", "text", "text", 
                                        "text", "text", "numeric", "text", 
                                        "text", "numeric", "numeric", "numeric", 
                                        "numeric", "numeric", "numeric", 
                                        "text", "text", "text", "text", "text"))
  
  
  Data_Mixed <- read_excel("Final_Data_Mixed.xlsx",
                           col_types = c("text", "numeric", 
                                         "numeric", "numeric", "numeric", 
                                         "numeric", "numeric", "numeric", 
                                         "numeric", "text", "text", "numeric", 
                                         "text", "text", "text", "text", "text", 
                                         "text", "text", "numeric", "text", 
                                         "text", "numeric", "numeric", "numeric", 
                                         "numeric", "numeric", "numeric", 
                                         "text", "text", "text", "text", "text"))
  
  
  
  Data_Losses <- read_excel("Final_Data_Losses.xlsx", 
                            col_types = c( "text", "numeric", 
                                          "numeric", "numeric", "numeric", 
                                          "numeric", "numeric", "numeric", 
                                          "numeric", "text", "text", "numeric", 
                                          "text", "text", "text", "text", "text", 
                                          "text", "text", "numeric", "text", 
                                          "text", "numeric", "numeric", "numeric", 
                                          "numeric", "numeric", "numeric", 
                                          "text", "text", "text", "text", "text"))
  
  
  
#####################  
# Z-Transformation ## 
#####################
  
  Data_Gains<- escalc(measure= "ZCOR", ri= `R_Recode`, ni= `N`, 
                      data=Data_Gains, 
                      slab=paste(Author, Year))
  
  Data_Mixed<- escalc(measure= "ZCOR", ri= `R_Recode`, ni= `N`, 
                      data=Data_Mixed, 
                      slab=paste(Author, Year))
  
  
  Data_Losses<- escalc(measure= "ZCOR", ri= `R_Recode`, ni= `N`, 
                       data=Data_Losses, 
                       slab=paste(Author, Year))   
    
#######################################  
## Random-Effect Meta-Analysis Gains ##   
#######################################  
  
  Res_Gain <- rma(yi, vi, data=Data_Gains, method = "REML") 
  Res_Gain 
  predict(Res_Gain, digits=2, transf=transf.ztor)
  confint(Res_Gain)  

  

###############################    
## Influential Studies Gains ##  
############################### 

  Inf_Gain <- influence(Res_Gain)
  print(Inf_Gain, digits=2)
  plot(Inf_Gain)
  plot(Inf_Gain, plotdfb = TRUE)
  leave1out(Res_Gain, digits = 3)
  
    
  
  
################################  
##     Forest Plot Gains      ##  
################################  

  forest(Res_Gain)
  
  
############################
## Publication Bias Gains ##     
############################ 
  
  funnel(Res_Gain)
  regtest(Res_Gain)
  ranktest(Res_Gain)
  
  
##############################
## Moderator Analysis Gains ##    
##############################  
 
  Res_Gain_MF_Ration <-rma(yi, vi, mods = ~ MF_Ratio, data=Data_Gains, method = "REML")
  Res_Gain_MF_Ration
  
  Res_Gain_Avrg_Age <-rma(yi, vi, mods = ~ Avrg_Age, data=Data_Gains, method = "REML")
  Res_Gain_Avrg_Age 
  
  Res_Gain_Sample_Type <-rma(yi, vi, mods = ~ factor(Sample_Type), data=Data_Gains, method = "REML")
  Res_Gain_Sample_Type
  
  Res_Gain_Avrg_Pay <- rma(yi, vi, mods = ~ Avrg_Pay_., data=Data_Gains, method = "REML")
  Res_Gain_Avrg_Pay
  
  Res_Gain_CAM <- rma(yi, vi, mods = ~factor(CAM), data=Data_Gains, method = "REML") 
  Res_Gain_CAM  
  
  Res_Gain_Decision_Task <- rma(yi, vi, mods = ~ factor(Decision_Task), data=Data_Gains, method = "REML") 
  Res_Gain_Decision_Task
  
  Res_Gain_Certain_Option <- rma(yi, vi, mods = ~ factor(Certain_Option), data=Data_Gains, method = "REML")
  Res_Gain_Certain_Option
  
  Res_Gain_Probabilities <- rma(yi, vi, mods = ~ factor(Probabilities), data=Data_Gains, method = "REML")
  Res_Gain_Probabilities
  
  Res_Gain_Payoff_Safer_Choice <- rma(yi, vi, mods = ~ factor(Payoff_Safer_Choice), data=Data_Gains, method = "REML")
  Res_Gain_Payoff_Safer_Choice
  
  Res_Gain_Payoff_Riskier_Choice <- rma(yi, vi, mods = ~ factor(Payoff_Riskier_Choice), data=Data_Gains, method = "REML")
  Res_Gain_Payoff_Riskier_Choice
  
  Res_Gain_Incentivized <-rma(yi, vi, mods = ~ factor(Incentivized), data=Data_Gains, method = "REML")
  Res_Gain_Incentivized
  
  Res_Gain_Possible_RA_Choices <- rma(yi, vi, mods = ~ X._Possible_RA_Choices , data=Data_Gains, method = "REML")
  Res_Gain_Possible_RA_Choices
  
  Res_Gain_Primary_Purpose <- rma(yi, vi, mods = ~ factor(Primary_Purpose), data=Data_Gains, method = "REML")
  Res_Gain_Primary_Purpose
  
  Res_Gain_Imputed_Beta <-rma(yi, vi, mods = ~ factor(Imputed_Beta), data=Data_Gains, method = "REML")
  Res_Gain_Imputed_Beta 
  
  
#######################################  
## Random-Effect Meta-Analysis Mixed ##   
#######################################  
  
  Res_Mixed <- rma(yi, vi, data=Data_Mixed, method = "REML") 
  Res_Mixed 
  predict(Res_Mixed, digits=2, transf=transf.ztor)
  confint(Res_Mixed)  
  
  
  
###############################    
## Influential Studies Mixed ##  
############################### 
  
  Inf_Mixed <- influence(Res_Mixed)
  print(Inf_Mixed, digits=2)
  plot(Inf_Mixed)
  plot(Inf_Mixed, plotdfb = TRUE)
  leave1out(Res_Mixed)
    
    
################################  
## Forest & Plot Mixed        ##  
################################  

  forest(Res_Mixed) 
    
############################
## Publication Bias Mixed ##     
############################ 
  
  funnel(Res_Mixed)
  regtest(Res_Mixed)
  ranktest(Res_Mixed)
  
  
##############################
## Moderator Analysis Mixed ##    
##############################   
  
  Res_Mixed_MF_Ratio <-rma(yi, vi, mods = ~ MF_Ratio, data=Data_Mixed, method = "REML")
  Res_Mixed_MF_Ratio 
  
  Res_Mixed_Avrg_Age <-rma(yi, vi, mods = ~ Avrg_Age, data=Data_Mixed, method = "REML")
  Res_Mixed_Avrg_Age 
  
  Res_Mixed_Sample_Type <-rma(yi, vi, mods = ~ factor(Sample_Type), data=Data_Mixed, method = "REML")
  Res_Mixed_Sample_Type
  
  Res_Mixed_Avrg_Pay <- rma(yi, vi, mods = ~ Avrg_Pay_., data=Data_Mixed, method = "REML")
  Res_Mixed_Avrg_Pay
  
  Res_Mixed_CAM <- rma(yi, vi, mods = ~ factor(CAM), data=Data_Mixed, method = "REML") 
  Res_Mixed_CAM  
  
  Res_Mixed_Decision_Task <- rma(yi, vi, mods = ~ factor(Decision_Task), data=Data_Mixed, method = "REML") 
  Res_Mixed_Decision_Task
  
  Res_Mixed_Certain_Option <- rma(yi, vi, mods = ~ factor(Certain_Option), data=Data_Mixed, method = "REML")
  Res_Mixed_Certain_Option
  
  Res_Mixed_Probabilities <- rma(yi, vi, mods = ~ factor(Probabilities), data=Data_Mixed, method = "REML")
  Res_Mixed_Probabilities
  
  Res_Mixed_Payoff_Safer_Choice <- rma(yi, vi, mods = ~ factor(Payoff_Safe_Choice), data=Data_Mixed, method = "REML")
  Res_Mixed_Payoff_Safer_Choice
  
  Res_Mixed_Payoff_Riskier_Choice <- rma(yi, vi, mods = ~ factor(Payoff_Risky_Choice), data=Data_Mixed, method = "REML")
  Res_Mixed_Payoff_Riskier_Choice
  
  Res_Mixed_Incentivized <-rma(yi, vi, mods = ~ factor(Incentivized), data=Data_Mixed, method = "REML")
  Res_Mixed_Incentivized
  
  Res_Mixed_Possible_RA_Choices <- rma(yi, vi, mods = ~ X._Possible_RA_Choices , data=Data_Mixed, method = "REML")
  Res_Mixed_Possible_RA_Choices
  
  Res_Mixed_Primary_Purpose <- rma(yi, vi, mods = ~ factor(Primary_Purpose), data=Data_Mixed, method = "REML")
  Res_Mixed_Primary_Purpose
  
  Res_Mixed_Imputed_Beta <-rma(yi, vi, mods = ~ factor(Imputed_Beta), data=Data_Mixed, method = "REML")
  Res_Mixed_Imputed_Beta 
  

  
########################################  
## Random-Effect Meta-Analysis Losses ##   
########################################  
  
  Res_Losses <- rma(yi, vi, data=Data_Losses, method = "REML") 
  Res_Losses 
  predict(Res_Losses, digits=2, transf=transf.ztor)
  confint(Res_Losses)  
    
  
  
################################    
## Influential Studies Losses ##  
################################ 
  
    
  Inf_Losses <- influence(Res_Losses)
  plot(Inf_Losses)
  plot(Inf_Losses, plotdfb = TRUE)
  print(Inf_Losses, digits=2)  
    
  
  
#################################  
## Forest Plot Losses          ##  
#################################  
  
  forest(Res_Losses)
  
  
#############################
## Publication Bias Losses ##     
############################# 
  
  funnel(Res_Losses)
  regtest(Res_Losses)
  ranktest(Res_Losses)
  
  
  
###############################
## Moderator Analysis Losses ##    
############################### 
 
  Res_Losses_MF_Ratio <-rma(yi, vi, mods = ~ MF_Ratio, data=Data_Losses, method = "REML")
  Res_Losses_MF_Ratio 
  
  Res_Losses_Avrg_Age <-rma(yi, vi, mods = ~ Avrg_Age, data=Data_Losses, method = "REML")
  Res_Losses_Avrg_Age 
  
  Res_Losses_Sample_Type <-rma(yi, vi, mods = ~ factor(Sample_Type), data=Data_Losses, method = "REML")
  Res_Losses_Sample_Type
  
  Res_Losses_Avrg_Pay <- rma(yi, vi, mods = ~ Avrg_Pay_., data=Data_Losses, method = "REML")
  Res_Losses_Avrg_Pay
  
  Res_Losses_CAM <- rma(yi, vi, mods = ~ factor(CAM), data=Data_Losses, method = "REML") 
  Res_Losses_CAM  
  
  Res_Losses_Decision_Task <- rma(yi, vi, mods = ~ factor(Decision_Task), data=Data_Losses, method = "REML") 
  Res_Losses_Decision_Task
  
  Res_Losses_Certain_Option <- rma(yi, vi, mods = ~ factor(Certain_Option), data=Data_Losses, method = "REML")
  Res_Losses_Certain_Option
  
  Res_Losses_Probabilities <- rma(yi, vi, mods = ~ factor(Probabilities), data=Data_Losses, method = "REML")
  Res_Losses_Probabilities
  
  Res_Losses_Payoff_Safer_Choice <- rma(yi, vi, mods = ~ factor(Payoff_Safe_Choice), data=Data_Losses, method = "REML")
  Res_Losses_Payoff_Safer_Choice
  
  Res_Losses_Payoff_Riskier_Choice <- rma(yi, vi, mods = ~ factor(Payoff_Risky_Choice), data=Data_Losses, method = "REML")
  Res_Losses_Payoff_Riskier_Choice
  
  Res_Losses_Incentivized <-rma(yi, vi, mods = ~ factor(Incentivized), data=Data_Losses, method = "REML")
  Res_Losses_Incentivized
  
  Res_Losses_Possible_RA_Choices <- rma(yi, vi, mods = ~ X._Possible_RA_Choices , data=Data_Losses, method = "REML")
  Res_Losses_Possible_RA_Choices
  
  Res_Losses_Primary_Purpose <- rma(yi, vi, mods = ~ factor(Primary_Purpose), data=Data_Losses, method = "REML")
  Res_Losses_Primary_Purpose
  
  Res_Losses_Imputed_Beta <-rma(yi, vi, mods = ~ factor(Imputed_Beta), data=Data_Losses, method = "REML")
  Res_Losses_Imputed_Beta 
  
  
  

  
  
  
  
      
  
      