#############################################################################
#############################################################################
###############                                                    ##########
###############       Cognitive Ability and Risk Aversion:         ##########
###############  A systematic Literature Review and Meta-Analysis  ##########
###############                                                    ##########
###############                  (Females Only)                    ##########
###############                                                    ##########
###############                                                    ##########
#############################################################################
#############################################################################


#############################################################################
##                                                                         ##
##  This R-script replicates the results from the paper:"Cognitive Ability ##
##  and Risk Aversion: A systematic Review and Meta-Analysis".             ##
##                                                                         ##
#############################################################################


###############################
##       Load packages       ##
###############################

library("metafor")
library("dplyr")
library("readxl")


################################################ 
## Set working directory to data file path....## 
################################################

  setwd("~/Documents/Articles/Cognitive Ability & Risk Aversion (JDM)/Final Resubmission")


####################
## Load data.... ###
####################  

Data_Gains<- read_excel("Final_Data_Gains.xlsx", 
                        col_types = c("text", "numeric", 
                                      "numeric", "numeric", "numeric", 
                                      "numeric", "numeric", "numeric", 
                                      "numeric", "text", "text", "numeric", 
                                      "text", "text", "text", "text", "text", 
                                      "text", "text", "numeric", "text", 
                                      "text", "numeric", "numeric", "numeric", 
                                      "numeric", "numeric", "numeric", 
                                      "text", "text", "text", "text", "text"))


Data_Mixed <- read_excel("Final_Data_Mixed.xlsx",
                         col_types = c("text", "numeric", 
                                       "numeric", "numeric", "numeric", 
                                       "numeric", "numeric", "numeric", 
                                       "numeric", "text", "text", "numeric", 
                                       "text", "text", "text", "text", "text", 
                                       "text", "text", "numeric", "text", 
                                       "text", "numeric", "numeric", "numeric", 
                                       "numeric", "numeric", "numeric", 
                                       "text", "text", "text", "text", "text"))



Data_Losses <- read_excel("Final_Data_Losses.xlsx", 
                          col_types = c("text", "numeric", 
                                        "numeric", "numeric", "numeric", 
                                        "numeric", "numeric", "numeric", 
                                        "numeric", "text", "text", "numeric", 
                                        "text", "text", "text", "text", "text", 
                                        "text", "text", "numeric", "text", 
                                        "text", "numeric", "numeric", "numeric", 
                                        "numeric", "numeric", "numeric", 
                                        "text", "text", "text", "text", "text"))



#####################  
# Z-Transformation ## 
#####################

Data_Gains<- escalc(measure= "ZCOR", ri= `R_Female_Recode`, ni= `Female`, 
                    data=Data_Gains, 
                    slab=paste(Author, Year))

Data_Mixed<- escalc(measure= "ZCOR", ri= `R_Female_Recode`, ni= `Female`, 
                    data=Data_Mixed, 
                    slab=paste(Author, Year))


Data_Losses<- escalc(measure= "ZCOR", ri= `R_Female_Recode`, ni= `Female`, 
                     data=Data_Losses, 
                     slab=paste(Author, Year))   

####################################################  
## Random-Effect Meta-Analysis Gains Females Only ##   
####################################################  

Res_Gain_Female <- rma(yi, vi, data=Data_Gains, method = "REML") 
Res_Gain_Female 
predict(Res_Gain_Female, digits=2, transf=transf.ztor)
confint(Res_Gain_Female)  



############################################    
## Influential Studies Gains Females Only ##  
############################################ 

Inf_Gain_Female <- influence(Res_Gain_Female)
print(Inf_Gain_Female, digits=2) 
plot(Inf_Gain_Female)
plot(Inf_Gain_Female, plotdfb = TRUE)


Data_Gains_Inf_Female <- Data_Gains
Data_Gains_Inf_Female <- Data_Gains_Inf_Female[-c(83,88, 51),]
Res_Gain_Inf_Female <- rma(yi, vi, data=Data_Gains_Inf_Female, method = "REML") 
Res_Gain_Inf_Female 
predict(Res_Gain_Inf_Female, digits=2, transf=transf.ztor)
confint(Res_Gain_Inf_Female)  

############################################  
## Forest Plot Gains Female Only          ##  
############################################  

forest(Res_Gain_Female)



########################################
## Publication Bias Gains Female Only ##     
######################################## 

funnel(Res_Gain_Female)
regtest(Res_Gain_Female)
ranktest(Res_Gain_Female)



###########################################
## Moderator Analysis Gains Females Only ##    
###########################################  

Res_Gain_Sample_Type_Female <-rma(yi, vi, mods = ~ factor(Sample_Type), data=Data_Gains, method = "REML")
Res_Gain_Sample_Type_Female

Res_Gain_Avrg_Pay_Female <- rma(yi, vi, mods = ~ Avrg_Pay_., data=Data_Gains, method = "REML")
Res_Gain_Avrg_Pay_Female

Res_Gain_CAM_Female <- rma(yi, vi, mods = ~ factor(CAM), data=Data_Gains, method = "REML") 
Res_Gain_CAM_Female  

Res_Gain_Decision_Task_Female <- rma(yi, vi, mods = ~ factor(Decision_Task), data=Data_Gains, method = "REML") 
Res_Gain_Decision_Task_Female

Res_Gain_Certain_Option_Female <- rma(yi, vi, mods = ~ factor(Certain_Option), data=Data_Gains, method = "REML")
Res_Gain_Certain_Option_Female

Res_Gain_Probabilities_Female <- rma(yi, vi, mods = ~ factor(Probabilities), data=Data_Gains, method = "REML")
Res_Gain_Probabilities_Female

Res_Gain_Payoff_Safer_Choice_Female <- rma(yi, vi, mods = ~ factor(Payoff_Safer_Choice), data=Data_Gains, method = "REML")
Res_Gain_Payoff_Safer_Choice_Female

Res_Gain_Payoff_Riskier_Choice_Female <- rma(yi, vi, mods = ~ factor(Payoff_Riskier_Choice), data=Data_Gains, method = "REML")
Res_Gain_Payoff_Riskier_Choice_Female

Res_Gain_Incentivized_Female <-rma(yi, vi, mods = ~ factor(Incentivized), data=Data_Gains, method = "REML")
Res_Gain_Incentivized_Female

Res_Gain_Possible_RA_Choices_Female <- rma(yi, vi, mods = ~ X._Possible_RA_Choices , data=Data_Gains, method = "REML")
Res_Gain_Possible_RA_Choices_Female

Res_Gain_Primary_Purpose_Female <- rma(yi, vi, mods = ~ factor(Primary_Purpose), data=Data_Gains, method = "REML")
Res_Gain_Primary_Purpose_Female

Res_Gain_Imputed_Beta_Female <-rma(yi, vi, mods = ~ factor(Imputed_Beta), data=Data_Gains, method = "REML")
Res_Gain_Imputed_Beta_Female 



####################################################  
## Random-Effect Meta-Analysis Mixed Females Only ##   
####################################################  

Res_Mixed_Female <- rma(yi, vi, data=Data_Mixed, method = "REML") 
Res_Mixed_Female 
predict(Res_Mixed_Female, digits=2, transf=transf.ztor)
confint(Res_Mixed_Female)  



############################################    
## Influential Studies Mixed Females Only ##  
############################################ 

Inf_Mixed_Female <- influence(Res_Mixed_Female)
print(Inf_Mixed_Female, digits=2)
plot(Inf_Mixed_Female)
plot(Inf_Mixed_Female, plotdfb = TRUE)
leave1out(Res_Mixed_Female)


####################################  
## Forest Plot Mixed Females Only ##  
####################################  

forest(Res_Mixed_Female)


#########################################
## Publication Bias Mixed Females Only ##     
######################################### 

funnel(Res_Mixed_Female)
regtest(Res_Mixed_Female)
ranktest(Res_Mixed_Female)


###########################################
## Moderator Analysis Mixed Females Only ##    
###########################################   

Res_Mixed_Sample_Type_Female <-rma(yi, vi, mods = ~ factor(Sample_Type), data=Data_Mixed, method = "REML")
Res_Mixed_Sample_Type_Female

Res_Mixed_Avrg_Pay_Female <- rma(yi, vi, mods = ~ Avrg_Pay_., data=Data_Mixed, method = "REML")
Res_Mixed_Avrg_Pay_Female

Res_Mixed_CAM_Female <- rma(yi, vi, mods = ~ factor(CAM), data=Data_Mixed, method = "REML") 
Res_Mixed_CAM_Female  

Res_Mixed_Decision_Task_Female <- rma(yi, vi, mods = ~ factor(Decision_Task), data=Data_Mixed, method = "REML") 
Res_Mixed_Decision_Task_Female

Res_Mixed_Certain_Option_Female <- rma(yi, vi, mods = ~ factor(Certain_Option), data=Data_Mixed, method = "REML")
Res_Mixed_Certain_Option_Female

Res_Mixed_Probabilities_Female <- rma(yi, vi, mods = ~ factor(Probabilities), data=Data_Mixed, method = "REML")
Res_Mixed_Probabilities_Female

Res_Mixed_Payoff_Safer_Choice_Female <- rma(yi, vi, mods = ~ factor(Payoff_Safe_Choice), data=Data_Mixed, method = "REML")
Res_Mixed_Payoff_Safer_Choice_Female

Res_Mixed_Payoff_Riskier_Choice_Female <- rma(yi, vi, mods = ~ factor(Payoff_Risky_Choice), data=Data_Mixed, method = "REML")
Res_Mixed_Payoff_Riskier_Choice_Female

Res_Mixed_Incentivized_Female <-rma(yi, vi, mods = ~ factor(Incentivized), data=Data_Mixed, method = "REML")
Res_Mixed_Incentivized_Female

Res_Mixed_Possible_RA_Choices_Female <- rma(yi, vi, mods = ~ X._Possible_RA_Choices , data=Data_Mixed, method = "REML")
Res_Mixed_Possible_RA_Choices_Female

Res_Mixed_Primary_Purpose_Female <- rma(yi, vi, mods = ~ factor(Primary_Purpose), data=Data_Mixed, method = "REML")
Res_Mixed_Primary_Purpose_Female

Res_Mixed_Imputed_Beta_Female <-rma(yi, vi, mods = ~ factor(Imputed_Beta), data=Data_Mixed, method = "REML")
Res_Mixed_Imputed_Beta_Female 



#####################################################  
## Random-Effect Meta-Analysis Losses Females Only ##   
#####################################################  

Res_Losses_Female <- rma(yi, vi, data=Data_Losses, method = "REML") 
Res_Losses_Female  
predict(Res_Losses_Female, digits=2, transf=transf.ztor)
confint(Res_Losses_Female)  



##############################################    
## Influential Studies Losses  Females Only ##  
############################################## 


Inf_Losses_Female <- influence(Res_Losses_Female)
print(Inf_Losses_Female, digits=2)
plot(Inf_Losses_Female)
plot(Inf_Losses_Female, plotdfb = TRUE)



#####################################  
## Forest Plot Losses Females Only ##  
#####################################  

forest(Res_Losses_Female)


##########################################
## Publication Bias Losses Females Only ##     
########################################## 

funnel(Res_Losses_Female)
regtest(Res_Losses_Female)
ranktest(Res_Losses_Female)



############################################
## Moderator Analysis Losses Females Only ##    
############################################ 

Res_Losses_Sample_Type_Female <-rma(yi, vi, mods = ~ factor(Sample_Type), data=Data_Losses, method = "REML")
Res_Losses_Sample_Type_Female

Res_Losses_Avrg_Pay_Female <- rma(yi, vi, mods = ~ Avrg_Pay_., data=Data_Losses, method = "REML")
Res_Losses_Avrg_Pay_Female

Res_Losses_CAM_Female <- rma(yi, vi, mods = ~ factor(CAM), data=Data_Losses, method = "REML") 
Res_Losses_CAM_Female  

Res_Losses_Decision_Task_Female <- rma(yi, vi, mods = ~ factor(Decision_Task), data=Data_Losses, method = "REML") 
Res_Losses_Decision_Task_Female

Res_Losses_Certain_Option_Female <- rma(yi, vi, mods = ~ factor(Certain_Option), data=Data_Losses, method = "REML")
Res_Losses_Certain_Option_Female

Res_Losses_Probabilities_Female <- rma(yi, vi, mods = ~ factor(Probabilities), data=Data_Losses, method = "REML")
Res_Losses_Probabilities_Female

Res_Losses_Payoff_Safer_Choice_Female <- rma(yi, vi, mods = ~ factor(Payoff_Safe_Choice), data=Data_Losses, method = "REML")
Res_Losses_Payoff_Safer_Choice_Female

Res_Losses_Payoff_Riskier_Choice_Female <- rma(yi, vi, mods = ~ factor(Payoff_Risky_Choice), data=Data_Losses, method = "REML")
Res_Losses_Payoff_Riskier_Choice_Female

Res_Losses_Incentivized_Female <-rma(yi, vi, mods = ~ factor(Incentivized), data=Data_Losses, method = "REML")
Res_Losses_Incentivized_Female

Res_Losses_Possible_RA_Choices_Female<- rma(yi, vi, mods = ~ X._Possible_RA_Choices , data=Data_Losses, method = "REML")
Res_Losses_Possible_RA_Choices_Female

Res_Losses_Primary_Purpose_Female <- rma(yi, vi, mods = ~ factor(Primary_Purpose), data=Data_Losses, method = "REML")
Res_Losses_Primary_Purpose_Female

Res_Losses_Imputed_Beta_Female <-rma(yi, vi, mods = ~ factor(Imputed_Beta), data=Data_Losses, method = "REML")
Res_Losses_Imputed_Beta_Female 







